@@ -8,14 +8,15 @@
 #define FILEMETADATAWIDGETTEST_H
 
 #include <filemetadatawidget.h>
+#include <QByteArray>
+#include <QMap>
+#include <QString>
 
 class FileMetadataWidgetTest : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
     void initTestCase();
-    void init();
-    void cleanup();
 
     void shouldSignalOnceWithoutFile();
     void shouldSignalOnceFile();
@@ -25,8 +26,8 @@ private Q_SLOTS:
     void shouldShowMultiValueProperties();
 
 private:
-    Baloo::FileMetaDataWidget *m_widget;
     bool m_mayTestRating = false;
+    QMap<QByteArray, QString> m_sampleFiles;
 };
 
 #endif // FILEMETADATAWIDGETTEST_H
